@@ -42,6 +42,7 @@
 		NOTIFY_MENTION: 2,
 		NOTIFY_NEVER: 3,
 
+
 		/* Must stay in sync with values in "lib/Room.php". */
 		FLAG_DISCONNECTED: 0,
 		FLAG_IN_CALL: 1,
@@ -52,6 +53,7 @@
 		ROOM_TYPE_ONE_TO_ONE: 1,
 		ROOM_TYPE_GROUP: 2,
 		ROOM_TYPE_PUBLIC: 3,
+		ROOM_TYPE_CHANGELOG: 4,
 
 		/** @property {OCA.SpreedMe.Models.Room} activeRoom  */
 		activeRoom: null,
@@ -76,7 +78,8 @@
 		_participants: null,
 		/** @property {OCA.SpreedMe.Views.ParticipantView} _participantsView  */
 		_participantsView: null,
-		displayedGuestNameHint: false,
+		/** @property {OCA.SpreedMe.Views.CollectionsView} _collectionsView */
+		_collectionsView: null,
 		fullscreenDisabled: true,
 		_searchTerm: '',
 		guestNick: null,
@@ -112,16 +115,11 @@
 							});
 						});
 
-						//Add custom entry to create a new empty group or public room
+						// Add custom entry to create a new empty group or public room
 						if (OCA.SpreedMe.app._searchTerm === '') {
-							results.unshift({
-								id: "create-public-room",
-								displayName: t('spreed', 'New public conversation'),
-								type: "createPublicRoom"
-							});
 							results.unshift({
 								id: "create-group-room",
-								displayName: t('spreed', 'New group conversation'),
+								displayName: t('spreed', 'Enter name for a new conversation'),
 								type: "createGroupRoom"
 							});
 						} else {
@@ -137,7 +135,7 @@
 							});
 							results.push({
 								id: "create-public-room",
-								displayName: t('spreed', '{name} (public)', { name: shortenedName }),
+								displayName: shortenedName,
 								type: "createPublicRoom"
 							});
 						}
@@ -153,7 +151,7 @@
 				},
 				formatResult: function (element) {
 					if (element.type === "createPublicRoom") {
-						return '<span><div class="avatar icon icon-public"></div>' + escapeHTML(element.displayName) + '</span>';
+						return '<span><div class="avatar icon icon-public"></div>' + t('spreed', '{name} (public)', { name: element.displayName }) + '</span>';
 					}
 
 					if (element.type === "createGroupRoom" || element.type === 'group') {
@@ -176,10 +174,14 @@
 						this.connection.createGroupVideoCall(e.val, '');
 						break;
 					case 'createPublicRoom':
-						this.connection.createPublicVideoCall(OCA.SpreedMe.app._searchTerm);
+						if (OCA.SpreedMe.app._searchTerm !== '') {
+							this.connection.createPublicVideoCall(OCA.SpreedMe.app._searchTerm);
+						}
 						break;
 					case 'createGroupRoom':
-						this.connection.createGroupVideoCall('', OCA.SpreedMe.app._searchTerm);
+						if (OCA.SpreedMe.app._searchTerm !== '') {
+							this.connection.createGroupVideoCall('', OCA.SpreedMe.app._searchTerm);
+						}
 						break;
 					default:
 						console.log('Unknown type', e.object.type);
@@ -300,6 +302,20 @@
 			delete this._participantsView;
 			delete this._participants;
 		},
+		_showCollectionsView: function() {
+			this._collectionsView = new OCA.SpreedMe.Views.CollectionsView({
+				room: this.activeRoom,
+				id: 'collectionsTabView'
+			});
+
+			this._collectionsView.listenTo(this._rooms, 'change:active', function(model, active) {
+				if (active) {
+					this.setRoom(model);
+				}
+			});
+
+			this._sidebarView.addTab('collections', { label: t('spreed', 'Projects'), icon: 'icon-projects' }, this._collectionsView);
+		},
 		/**
 		 * @param {string} token
 		 */
@@ -328,7 +344,6 @@
 					self.stopListening(self.activeRoom, 'change:displayName');
 					self.stopListening(self.activeRoom, 'change:participantFlags');
 
-					var participants;
 					if (OC.getCurrentUser().uid) {
 						roomChannel.trigger('active', token);
 
@@ -337,15 +352,6 @@
 								self.activeRoom = room;
 							}
 						});
-						participants = self.activeRoom.get('participants');
-					} else {
-						// The public page supports only a single room, so the
-						// active room is already the room for the given token.
-						participants = self.activeRoom.get('participants');
-					}
-					// Disable video when entering a room with more than 5 participants.
-					if (participants && Object.keys(participants).length > 5) {
-						self.disableVideo();
 					}
 
 					self._emptyContentView.setActiveRoom(self.activeRoom);
@@ -386,12 +392,10 @@
 			}
 
 			if (inCall) {
-				$('#video-speaking').show();
 				$('#videos').show();
 				$('#screens').show();
 				$('#emptycontent').hide();
 			} else {
-				$('#video-speaking').hide();
 				$('#videos').hide();
 				$('#screens').hide();
 				$('#emptycontent').show();
@@ -406,7 +410,9 @@
 			// happens it will overlap with the content area (the narrower the
 			// window the larger the overlap). Due to this the sidebar is opened
 			// automatically only if it will not overlap with the content area.
-			if ($(window).width() > 1111) {
+			if (this.activeRoom.get('type') === this.ROOM_TYPE_CHANGELOG) {
+				this._sidebarView.close();
+			} else if (this.activeRoom.get('type') !== this.ROOM_TYPE_CHANGELOG && $(window).width() > 1111) {
 				this._sidebarView.open();
 			}
 
@@ -416,6 +422,7 @@
 			});
 			this._sidebarView.setCallInfoView(callInfoView);
 
+			this._chatView.setRoom(this.activeRoom);
 			this._messageCollection.setRoomToken(this.activeRoom.get('token'));
 			this._messageCollection.receiveMessages();
 		},
@@ -451,6 +458,7 @@
 			this._messageCollection = new OCA.SpreedMe.Models.ChatMessageCollection(null, {token: null});
 			this._chatView = new OCA.SpreedMe.Views.ChatView({
 				collection: this._messageCollection,
+				model: this.activeRoom,
 				id: 'chatView',
 				guestNameModel: this._localStorageModel
 			});
@@ -551,7 +559,6 @@
 				this._chatView.$el.detach();
 				this._chatViewInMainView = false;
 
-				$('#video-speaking').hide();
 				$('#videos').hide();
 				$('#screens').hide();
 				$('#emptycontent').show();
@@ -581,13 +588,17 @@
 				OC.Util.History.replaceState({}, OC.generateUrl('/apps/spreed'));
 			});
 
-			this._mediaControlsView = new OCA.SpreedMe.Views.MediaControlsView({
+			this._localVideoView = new OCA.Talk.Views.LocalVideoView({
 				app: this,
 				webrtc: OCA.SpreedMe.webrtc,
 				sharedScreens: OCA.SpreedMe.sharedScreens,
 			});
-			this._mediaControlsView.render();
-			$('#localVideoContainer .nameIndicator').replaceWith(this._mediaControlsView.$el);
+			this._localVideoView.render();
+			// Ensure that the local video is not visible in the initial page.
+			this._localVideoView.$el.addClass('hidden');
+			$('#videos').append(this._localVideoView.$el);
+
+			this._mediaControlsView = this._localVideoView._mediaControlsView;
 
 			$(document).on('click', this.onDocumentClick);
 			OC.Util.History.addOnPopStateHandler(_.bind(this._onPopState, this));
@@ -605,6 +616,15 @@
 				}
 			}.bind(this));
 
+			this.signaling.on('joinCall', function() {
+				// Disable video when joining a call in a room with more than 5
+				// participants.
+				var participants = this.activeRoom.get('participants');
+				if (participants && Object.keys(participants).length > 5) {
+					this.setVideoEnabled(false);
+				}
+			}.bind(this));
+
 			$(window).unload(function () {
 				this.connection.leaveCurrentRoom();
 				this.signaling.disconnect();
@@ -623,6 +643,7 @@
 					}.bind(this));
 
 				this._showParticipantList();
+				this._showCollectionsView();
 			} else if (this.token) {
 				// The token is always defined in the public page (although not
 				// in the public share auth page).
@@ -656,7 +677,7 @@
 				this._mediaControlsView.setSharedScreens(OCA.SpreedMe.sharedScreens);
 			}
 
-			if (!OCA.SpreedMe.webrtc.capabilities.support) {
+			if (!OCA.SpreedMe.webrtc.capabilities.supportRTCPeerConnection) {
 				localMediaChannel.trigger('webRtcNotSupported');
 			} else {
 				localMediaChannel.trigger('waitingForPermissions');
@@ -670,7 +691,7 @@
 				this.callbackAfterMedia = null;
 			}
 
-			$('.videoView').removeClass('hidden');
+			this._localVideoView.$el.removeClass('hidden');
 			this.initAudioVideoSettings(configuration);
 
 			localMediaChannel.trigger('startLocalMedia');
@@ -681,10 +702,10 @@
 				this.callbackAfterMedia = null;
 			}
 
-			$('.videoView').removeClass('hidden');
+			this._localVideoView.$el.removeClass('hidden');
 			this.initAudioVideoSettings(configuration);
 
-			if (OCA.SpreedMe.webrtc.capabilities.support) {
+			if (OCA.SpreedMe.webrtc.capabilities.supportRTCPeerConnection) {
 				localMediaChannel.trigger('startWithoutLocalMedia');
 			}
 		},
@@ -702,29 +723,19 @@
 		},
 		initAudioVideoSettings: function(configuration) {
 			if (configuration.audio !== false) {
-				this._mediaControlsView.hasAudio();
-
-				if (this._mediaControlsView.audioDisabled) {
-					this._mediaControlsView.disableAudio();
-				} else {
-					this._mediaControlsView.enableAudio();
-				}
+				this._mediaControlsView.setAudioAvailable(true);
+				this._mediaControlsView.setAudioEnabled(this._mediaControlsView.audioEnabled);
 			} else {
-				this._mediaControlsView.disableAudio();
-				this._mediaControlsView.hasNoAudio();
+				this._mediaControlsView.setAudioEnabled(false);
+				this._mediaControlsView.setAudioAvailable(false);
 			}
 
 			if (configuration.video !== false) {
-				this._mediaControlsView.hasVideo();
-
-				if (this._mediaControlsView.videoDisabled) {
-					this.disableVideo();
-				} else {
-					this.enableVideo();
-				}
+				this._mediaControlsView.setVideoAvailable(true);
+				this.setVideoEnabled(this._mediaControlsView.videoEnabled);
 			} else {
-				this.disableVideo();
-				this._mediaControlsView.hasNoVideo();
+				this.setVideoEnabled(false);
+				this._mediaControlsView.setVideoAvailable(false);
 			}
 		},
 		enableFullscreen: function() {
@@ -758,43 +769,12 @@
 
 			this.fullscreenDisabled = true;
 		},
-		enableVideoUI: function() {
-			var avatarContainer = this._mediaControlsView.$el.closest('.videoView').find('.avatar-container');
-			var localVideo = this._mediaControlsView.$el.closest('.videoView').find('#localVideo');
-
-			avatarContainer.hide();
-			localVideo.show();
-		},
-		enableVideo: function() {
-			if (this._mediaControlsView.enableVideo()) {
-				this.enableVideoUI();
-			}
-		},
-		hideVideo: function() {
-			var avatarContainer = this._mediaControlsView.$el.closest('.videoView').find('.avatar-container');
-			var localVideo = this._mediaControlsView.$el.closest('.videoView').find('#localVideo');
-
-			var avatar = avatarContainer.find('.avatar');
-			var guestName = localStorage.getItem("nick");
-			if (OC.getCurrentUser().uid) {
-				avatar.avatar(OC.getCurrentUser().uid, 128);
-			} else {
-				avatar.imageplaceholder('?', guestName, 128);
-				avatar.css('background-color', '#b9b9b9');
-				if (this.displayedGuestNameHint === false) {
-					OC.Notification.showTemporary(t('spreed', 'Set your name in the chat window so other participants can identify you better.'));
-					this.displayedGuestNameHint = true;
-				}
+		setVideoEnabled: function(videoEnabled) {
+			if (!this._mediaControlsView.setVideoEnabled(videoEnabled)) {
+				return;
 			}
 
-			avatarContainer.removeClass('hidden');
-			avatarContainer.show();
-			localVideo.hide();
-		},
-		disableVideo: function() {
-			this._mediaControlsView.disableVideo();
-			// Always hide the video, even if "disableVideo" returned "false".
-			this.hideVideo();
+			this._localVideoView.setVideoEnabled(videoEnabled);
 		},
 		// Called from webrtc.js
 		disableScreensharingButton: function() {
@@ -829,10 +809,7 @@
 			this._localStorageModel.fetch();
 		},
 		_onChangeGuestName: function(newDisplayName) {
-			var avatar = $('#localVideoContainer').find('.avatar');
-
-			avatar.imageplaceholder('?', newDisplayName, 128);
-			avatar.css('background-color', '#b9b9b9');
+			this._localVideoView.setAvatar(undefined, newDisplayName);
 
 			if (OCA.SpreedMe.webrtc) {
 				console.log('_onChangeGuestName.webrtc');
