@@ -1,15 +1,6 @@
 OC.L10N.register(
     "spreed",
     {
-    "Validate SSL certificate" : "Validar certificado SSL",
-    "Delete server" : "Apagar servidor",
-    "Add new server" : "Adicionar novo servidor",
-    "Saved" : "Gravado",
-    "Shared secret" : "Segredo partilhado",
-    "UDP and TCP" : "UDP e TCP",
-    "UDP only" : "Só UDP",
-    "TCP only" : "Só TCP",
-    "TURN server protocols" : "Protocolos do servidor TURN",
     "Participants" : "Participantes",
     "Chat" : "Conversa",
     "Talk" : "Falar",
@@ -69,15 +60,15 @@ OC.L10N.register(
     "Demote from moderator" : "Relegar de moderador",
     "Promote to moderator" : "Promover a moderador",
     "Remove participant" : "Remover participante",
+    "Your screen" : "O seu ecrã",
+    "{participantName}'s screen" : "Ecrã de {nomeDeParticipante}",
+    "Guest's screen" : "Ecrã do convidado",
     "Close" : "Fechar",
     "Show screen" : "Mostrar ecrã",
     "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
     "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
     "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
     "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
-    "{participantName}'s screen" : "Ecrã de {nomeDeParticipante}",
-    "Guest's screen" : "Ecrã do convidado",
-    "Your screen" : "O seu ecrã",
     "(Duration %s)" : "(Duração %s)",
     "You attended a call with {user1}" : "Esteve numa chamada com {utilizador1}",
     "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {utilizador1} e {utilizador2}",
@@ -87,13 +78,17 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} convidou-o para {chamada}",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Foi convidado para uma sala de <strong>conversa</strong> ou recebeu uma <strong>chamada</strong>",
     "Talk to %s" : "Falar com %s",
-    ", " : ",",
     "{user} wants to talk with you" : "{utilizador} quer falar consigo",
     "A group call has started in {call}" : "Uma chamada de grupo começou em {chamada}",
-    "(group)" : "(grupo)",
-    "and you" : "e você",
-    "… %s" : "... %s",
-    "%s …" : "%s ...",
-    "… %s …" : "... %s ..."
+    "Validate SSL certificate" : "Validar certificado SSL",
+    "TURN server protocols" : "Protocolos do servidor TURN",
+    "UDP and TCP" : "UDP e TCP",
+    "UDP only" : "Só UDP",
+    "TCP only" : "Só TCP",
+    "Saved" : "Gravado",
+    "Shared secret" : "Segredo partilhado",
+    "Delete server" : "Apagar servidor",
+    "Add new server" : "Adicionar novo servidor",
+    ", " : ","
 },
 "nplurals=2; plural=(n != 1);");
